_**by Edgar Allan Poe**  
(published 1838)_

    

_And the will therein lieth, which dieth not. Who knoweth the mysteries of the will, with its vigor? For God is but a great will pervading all things by nature of its intentness. Man doth not yield himself to the angels, nor unto death utterly, save only through the weakness of his feeble will._  
_- Joseph Glanvill_  
  
I CANNOT, for my soul, remember how, when, or even precisely where, I first became acquainted with the lady Ligeia. Long years have since elapsed, and my memory is feeble through much suffering. Or, perhaps, I cannot now bring these points to mind, because, in truth, the character of my beloved, her rare learning, her singular yet placid cast of beauty, and the thrilling and enthralling eloquence of her low musical language, made their way into my heart by paces so steadily and stealthily progressive that they have been unnoticed and unknown. Yet I believe that I met her first and most frequently in some large, old, decaying city near the Rhine. Of her family --I have surely heard her speak. That it is of a remotely ancient date cannot be doubted. Ligeia! Ligeia! in studies of a nature more than all else adapted to deaden impressions of the outward world, it is by that sweet word alone --by Ligeia --that I bring before mine eyes in fancy the image of her who is no more. And now, while I write, a recollection flashes upon me that I have never known the paternal name of her who was my friend and my betrothed, and who became the partner of my studies, and finally the wife of my bosom. Was it a playful charge on the part of my Ligeia? or was it a test of my strength of affection, that I should institute no inquiries upon this point? or was it rather a caprice of my own --a wildly romantic offering on the shrine of the most passionate devotion? I but indistinctly recall the fact itself --what wonder that I have utterly forgotten the circumstances which originated or attended it? And, indeed, if ever she, the wan and the misty-winged Ashtophet of idolatrous Egypt, presided, as they tell, over marriages ill-omened, then most surely she presided over mine.  
  
There is one dear topic, however, on which my memory fails me not. It is the person of Ligeia. In stature she was tall, somewhat slender, and, in her latter days, even emaciated. I would in vain attempt to portray the majesty, the quiet ease, of her demeanor, or the incomprehensible lightness and elasticity of her footfall. She came and departed as a shadow. I was never made aware of her entrance into my closed study save by the dear music of her low sweet voice, as she placed her marble hand upon my shoulder. In beauty of face no maiden ever equalled her. It was the radiance of an opium-dream --an airy and spirit-lifting vision more wildly divine than the phantasies which hovered vision about the slumbering souls of the daughters of Delos. Yet her features were not of that regular mould which we have been falsely taught to worship in the classical labors of the heathen. "There is no exquisite beauty," says Bacon, Lord Verulam, speaking truly of all the forms and genera of beauty, without some strangeness in the proportion." Yet, although I saw that the features of Ligeia were not of a classic regularity --although I perceived that her loveliness was indeed "exquisite," and felt that there was much of "strangeness" pervading it, yet I have tried in vain to detect the irregularity and to trace home my own perception of "the strange." I examined the contour of the lofty and pale forehead --it was faultless --how cold indeed that word when applied to a majesty so divine! --the skin rivalling the purest ivory, the commanding extent and repose, the gentle prominence of the regions above the temples; and then the raven-black, the glossy, the luxuriant and naturally-curling tresses, setting forth the full force of the Homeric epithet, "hyacinthine!" I looked at the delicate outlines of the nose --and nowhere but in the graceful medallions of the Hebrews had I beheld a similar perfection. There were the same luxurious smoothness of surface, the same scarcely perceptible tendency to the aquiline, the same harmoniously curved nostrils speaking the free spirit. I regarded the sweet mouth. Here was indeed the triumph of all things heavenly --the magnificent turn of the short upper lip --the soft, voluptuous slumber of the under --the dimples which sported, and the color which spoke --the teeth glancing back, with a brilliancy almost startling, every ray of the holy light which fell upon them in her serene and placid, yet most exultingly radiant of all smiles. I scrutinized the formation of the chin --and here, too, I found the gentleness of breadth, the softness and the majesty, the fullness and the spirituality, of the Greek --the contour which the god Apollo revealed but in a dream, to Cleomenes, the son of the Athenian. And then I peered into the large eyes of Ligeia.  
  
For eyes we have no models in the remotely antique. It might have been, too, that in these eves of my beloved lay the secret to which Lord Verulam alludes. They were, I must believe, far larger than the ordinary eyes of our own race. They were even fuller than the fullest of the gazelle eyes of the tribe of the valley of Nourjahad. Yet it was only at intervals --in moments of intense excitement --that this peculiarity became more than slightly noticeable in Ligeia. And at such moments was her beauty --in my heated fancy thus it appeared perhaps --the beauty of beings either above or apart from the earth --the beauty of the fabulous Houri of the Turk. The hue of the orbs was the most brilliant of black, and, far over them, hung jetty lashes of great length. The brows, slightly irregular in outline, had the same tint. The "strangeness," however, which I found in the eyes, was of a nature distinct from the formation, or the color, or the brilliancy of the features, and must, after all, be referred to the expression. Ah, word of no meaning! behind whose vast latitude of mere sound we intrench our ignorance of so much of the spiritual. The expression of the eyes of Ligeia! How for long hours have I pondered upon it! How have I, through the whole of a midsummer night, struggled to fathom it! What was it --that something more profound than the well of Democritus --which lay far within the pupils of my beloved? What was it? I was possessed with a passion to discover. Those eyes! those large, those shining, those divine orbs! they became to me twin stars of Leda, and I to them devoutest of astrologers.  
  
There is no point, among the many incomprehensible anomalies of the science of mind, more thrillingly exciting than the fact --never, I believe, noticed in the schools --that, in our endeavors to recall to memory something long forgotten, we often find ourselves upon the very verge of remembrance, without being able, in the end, to remember. And thus how frequently, in my intense scrutiny of Ligeia's eyes, have I felt approaching the full knowledge of their expression --felt it approaching --yet not quite be mine --and so at length entirely depart! And (strange, oh strangest mystery of all!) I found, in the commonest objects of the universe, a circle of analogies to theat expression. I mean to say that, subsequently to the period when Ligeia's beauty passed into my spirit, there dwelling as in a shrine, I derived, from many existences in the material world, a sentiment such as I felt always aroused within me by her large and luminous orbs. Yet not the more could I define that sentiment, or analyze, or even steadily view it. I recognized it, let me repeat, sometimes in the survey of a rapidly-growing vine --in the contemplation of a moth, a butterfly, a chrysalis, a stream of running water. I have felt it in the ocean; in the falling of a meteor. I have felt it in the glances of unusually aged people. And there are one or two stars in heaven --(one especially, a star of the sixth magnitude, double and changeable, to be found near the large star in Lyra) in a telescopic scrutiny of which I have been made aware of the feeling. I have been filled with it by certain sounds from stringed instruments, and not unfrequently by passages from books. Among innumerable other instances, I well remember something in a volume of Joseph Glanvill, which (perhaps merely from its quaintness --who shall say?) never failed to inspire me with the sentiment; --"And the will therein lieth, which dieth not. Who knoweth the mysteries of the will, with its vigor? For God is but a great will pervading all things by nature of its intentness. Man doth not yield him to the angels, nor unto death utterly, save only through the weakness of his feeble will."  
  
Length of years, and subsequent reflection, have enabled me to trace, indeed, some remote connection between this passage in the English moralist and a portion of the character of Ligeia. An intensity in thought, action, or speech, was possibly, in her, a result, or at least an index, of that gigantic volition which, during our long intercourse, failed to give other and more immediate evidence of its existence. Of all the women whom I have ever known, she, the outwardly calm, the ever-placid Ligeia, was the most violently a prey to the tumultuous vultures of stern passion. And of such passion I could form no estimate, save by the miraculous expansion of those eyes which at once so delighted and appalled me --by the almost magical melody, modulation, distinctness and placidity of her very low voice --and by the fierce energy (rendered doubly effective by contrast with her manner of utterance) of the wild words which she habitually uttered.  
  
I have spoken of the learning of Ligeia: it was immense --such as I have never known in woman. In the classical tongues was she deeply proficient, and as far as my own acquaintance extended in regard to the modern dialects of Europe, I have never known her at fault. Indeed upon any theme of the most admired, because simply the most abstruse of the boasted erudition of the academy, have I ever found Ligeia at fault? How singularly --how thrillingly, this one point in the nature of my wife has forced itself, at this late period only, upon my attention! I said her knowledge was such as I have never known in woman --but where breathes the man who has traversed, and successfully, all the wide areas of moral, physical, and mathematical science? I saw not then what I now clearly perceive, that the acquisitions of Ligeia were gigantic, were astounding; yet I was sufficiently aware of her infinite supremacy to resign myself, with a child-like confidence, to her guidance through the chaotic world of metaphysical investigation at which I was most busily occupied during the earlier years of our marriage. With how vast a triumph --with how vivid a delight --with how much of all that is ethereal in hope --did I feel, as she bent over me in studies but little sought --but less known --that delicious vista by slow degrees expanding before me, down whose long, gorgeous, and all untrodden path, I might at length pass onward to the goal of a wisdom too divinely precious not to be forbidden!  
  
How poignant, then, must have been the grief with which, after some years, I beheld my well-grounded expectations take wings to themselves and fly away! Without Ligeia I was but as a child groping benighted. Her presence, her readings alone, rendered vividly luminous the many mysteries of the transcendentalism in which we were immersed. Wanting the radiant lustre of her eyes, letters, lambent and golden, grew duller than Saturnian lead. And now those eyes shone less and less frequently upon the pages over which I pored. Ligeia grew ill. The wild eyes blazed with a too --too glorious effulgence; the pale fingers became of the transparent waxen hue of the grave, and the blue veins upon the lofty forehead swelled and sank impetuously with the tides of the gentle emotion. I saw that she must die --and I struggled desperately in spirit with the grim Azrael. And the struggles of the passionate wife were, to my astonishment, even more energetic than my own. There had been much in her stern nature to impress me with the belief that, to her, death would have come without its terrors; --but not so. Words are impotent to convey any just idea of the fierceness of resistance with which she wrestled with the Shadow. I groaned in anguish at the pitiable spectacle. would have soothed --I would have reasoned; but, in the intensity of her wild desire for life, --for life --but for life --solace and reason were the uttermost folly. Yet not until the last instance, amid the most convulsive writhings of her fierce spirit, was shaken the external placidity of her demeanor. Her voice grew more gentle --grew more low --yet I would not wish to dwell upon the wild meaning of the quietly uttered words. My brain reeled as I hearkened entranced, to a melody more than mortal --to assumptions and aspirations which mortality had never before known.  
  
That she loved me I should not have doubted; and I might have been easily aware that, in a bosom such as hers, love would have reigned no ordinary passion. But in death only, was I fully impressed with the strength of her affection. For long hours, detaining my hand, would she pour out before me the overflowing of a heart whose more than passionate devotion amounted to idolatry. How had I deserved to be so blessed by such confessions? --how had I deserved to be so cursed with the removal of my beloved in the hour of her making them, But upon this subject I cannot bear to dilate. Let me say only, that in Ligeia's more than womanly abandonment to a love, alas! all unmerited, all unworthily bestowed, I at length recognized the principle of her longing with so wildly earnest a desire for the life which was now fleeing so rapidly away. It is this wild longing --it is this eager vehemence of desire for life --but for life --that I have no power to portray --no utterance capable of expressing.  
  
At high noon of the night in which she departed, beckoning me, peremptorily, to her side, she bade me repeat certain verses composed by herself not many days before. I obeyed her. --They were these:  
  
      Lo! 'tis a gala night  
      Within the lonesome latter years!  
      An angel throng, bewinged, bedight  
      In veils, and drowned in tears,  
      Sit in a theatre, to see  
      A play of hopes and fears,  
      While the orchestra breathes fitfully  
      The music of the spheres.  
  
      Mimes, in the form of God on high,  
      Mutter and mumble low,  
      And hither and thither fly --  
      Mere puppets they, who come and go  
      At bidding of vast formless things  
      That shift the scenery to and fro,  
      Flapping from out their Condor wings  
      Invisible Wo!  
  
      That motley drama! --oh, be sure  
      It shall not be forgot!  
      With its Phantom chased forever more,  
      By a crowd that seize it not,  
      Through a circle that ever returneth in  
      To the self-same spot,  
      And much of Madness and more of Sin  
      And Horror the soul of the plot.  
  
      But see, amid the mimic rout,  
      A crawling shape intrude!  
      A blood-red thing that writhes from out  
      The scenic solitude!  
      It writhes! --it writhes! --with mortal pangs  
      The mimes become its food,  
      And the seraphs sob at vermin fangs  
      In human gore imbued.  
  
      Out --out are the lights --out all!  
      And over each quivering form,  
      The curtain, a funeral pall,  
      Comes down with the rush of a storm,  
      And the angels, all pallid and wan,  
      Uprising, unveiling, affirm  
      That the play is the tragedy, "Man,"  
      And its hero the Conqueror Worm.  
  
"O God!" half shrieked Ligeia, leaping to her feet and extending her arms aloft with a spasmodic movement, as I made an end of these lines --"O God! O Divine Father! --shall these things be undeviatingly so? --shall this Conqueror be not once conquered? Are we not part and parcel in Thee? Who --who knoweth the mysteries of the will with its vigor? Man doth not yield him to the angels, nor unto death utterly, save only through the weakness of his feeble will."  
  
And now, as if exhausted with emotion, she suffered her white arms to fall, and returned solemnly to her bed of death. And as she breathed her last sighs, there came mingled with them a low murmur from her lips. I bent to them my ear and distinguished, again, the concluding words of the passage in Glanvill --"Man doth not yield him to the angels, nor unto death utterly, save only through the weakness of his feeble will."  
  
She died; --and I, crushed into the very dust with sorrow, could no longer endure the lonely desolation of my dwelling in the dim and decaying city by the Rhine. I had no lack of what the world calls wealth. Ligeia had brought me far more, very far more than ordinarily falls to the lot of mortals. After a few months, therefore, of weary and aimless wandering, I purchased, and put in some repair, an abbey, which I shall not name, in one of the wildest and least frequented portions of fair England. The gloomy and dreary grandeur of the building, the almost savage aspect of the domain, the many melancholy and time-honored memories connected with both, had much in unison with the feelings of utter abandonment which had driven me into that remote and unsocial region of the country. Yet although the external abbey, with its verdant decay hanging about it, suffered but little alteration, I gave way, with a child-like perversity, and perchance with a faint hope of alleviating my sorrows, to a display of more than regal magnificence within. --For such follies, even in childhood, I had imbibed a taste and now they came back to me as if in the dotage of grief. Alas, I feel how much even of incipient madness might have been discovered in the gorgeous and fantastic draperies, in the solemn carvings of Egypt, in the wild cornices and furniture, in the Bedlam patterns of the carpets of tufted gold! I had become a bounden slave in the trammels of opium, and my labors and my orders had taken a coloring from my dreams. But these absurdities must not pause to detail. Let me speak only of that one chamber, ever accursed, whither in a moment of mental alienation, I led from the altar as my bride --as the successor of the unforgotten Ligeia --the fair-haired and blue-eyed Lady Rowena Trevanion, of Tremaine.  
  
There is no individual portion of the architecture and decoration of that bridal chamber which is not now visibly before me. Where were the souls of the haughty family of the bride, when, through thirst of gold, they permitted to pass the threshold of an apartment so bedecked, a maiden and a daughter so beloved? I have said that I minutely remember the details of the chamber --yet I am sadly forgetful on topics of deep moment --and here there was no system, no keeping, in the fantastic display, to take hold upon the memory. The room lay in a high turret of the castellated abbey, was pentagonal in shape, and of capacious size. Occupying the whole southern face of the pentagon was the sole window --an immense sheet of unbroken glass from Venice --a single pane, and tinted of a leaden hue, so that the rays of either the sun or moon, passing through it, fell with a ghastly lustre on the objects within. Over the upper portion of this huge window, extended the trellice-work of an aged vine, which clambered up the massy walls of the turret. The ceiling, of gloomy-looking oak, was excessively lofty, vaulted, and elaborately fretted with the wildest and most grotesque specimens of a semi-Gothic, semi-Druidical device. From out the most central recess of this melancholy vaulting, depended, by a single chain of gold with long links, a huge censer of the same metal, Saracenic in pattern, and with many perforations so contrived that there writhed in and out of them, as if endued with a serpent vitality, a continual succession of parti-colored fires.  
  
Some few ottomans and golden candelabra, of Eastern figure, were in various stations about --and there was the couch, too --bridal couch --of an Indian model, and low, and sculptured of solid ebony, with a pall-like canopy above. In each of the angles of the chamber stood on end a gigantic sarcophagus of black granite, from the tombs of the kings over against Luxor, with their aged lids full of immemorial sculpture. But in the draping of the apartment lay, alas! the chief phantasy of all. The lofty walls, gigantic in height --even unproportionably so --were hung from summit to foot, in vast folds, with a heavy and massive-looking tapestry --tapestry of a material which was found alike as a carpet on the floor, as a covering for the ottomans and the ebony bed, as a canopy for the bed, and as the gorgeous volutes of the curtains which partially shaded the window. The material was the richest cloth of gold. It was spotted all over, at irregular intervals, with arabesque figures, about a foot in diameter, and wrought upon the cloth in patterns of the most jetty black. But these figures partook of the true character of the arabesque only when regarded from a single point of view. By a contrivance now common, and indeed traceable to a very remote period of antiquity, they were made changeable in aspect. To one entering the room, they bore the appearance of simple monstrosities; but upon a farther advance, this appearance gradually departed; and step by step, as the visitor moved his station in the chamber, he saw himself surrounded by an endless succession of the ghastly forms which belong to the superstition of the Norman, or arise in the guilty slumbers of the monk. The phantasmagoric effect was vastly heightened by the artificial introduction of a strong continual current of wind behind the draperies --giving a hideous and uneasy animation to the whole.  
  
In halls such as these --in a bridal chamber such as this --I passed, with the Lady of Tremaine, the unhallowed hours of the first month of our marriage --passed them with but little disquietude. That my wife dreaded the fierce moodiness of my temper --that she shunned me and loved me but little --I could not help perceiving; but it gave me rather pleasure than otherwise. I loathed her with a hatred belonging more to demon than to man. My memory flew back, (oh, with what intensity of regret!) to Ligeia, the beloved, the august, the beautiful, the entombed. I revelled in recollections of her purity, of her wisdom, of her lofty, her ethereal nature, of her passionate, her idolatrous love. Now, then, did my spirit fully and freely burn with more than all the fires of her own. In the excitement of my opium dreams (for I was habitually fettered in the shackles of the drug) I would call aloud upon her name, during the silence of the night, or among the sheltered recesses of the glens by day, as if, through the wild eagerness, the solemn passion, the consuming ardor of my longing for the departed, I could restore her to the pathway she had abandoned --ah, could it be forever? --upon the earth.  
  
About the commencement of the second month of the marriage, the Lady Rowena was attacked with sudden illness, from which her recovery was slow. The fever which consumed her rendered her nights uneasy; and in her perturbed state of half-slumber, she spoke of sounds, and of motions, in and about the chamber of the turret, which I concluded had no origin save in the distemper of her fancy, or perhaps in the phantasmagoric influences of the chamber itself. She became at length convalescent --finally well. Yet but a brief period elapsed, ere a second more violent disorder again threw her upon a bed of suffering; and from this attack her frame, at all times feeble, never altogether recovered. Her illnesses were, after this epoch, of alarming character, and of more alarming recurrence, defying alike the knowledge and the great exertions of her physicians. With the increase of the chronic disease which had thus, apparently, taken too sure hold upon her constitution to be eradicated by human means, I could not fail to observe a similar increase in the nervous irritation of her temperament, and in her excitability by trivial causes of fear. She spoke again, and now more frequently and pertinaciously, of the sounds --of the slight sounds --and of the unusual motions among the tapestries, to which she had formerly alluded.  
  
One night, near the closing in of September, she pressed this distressing subject with more than usual emphasis upon my attention. She had just awakened from an unquiet slumber, and I had been watching, with feelings half of anxiety, half of vague terror, the workings of her emaciated countenance. I sat by the side of her ebony bed, upon one of the ottomans of India. She partly arose, and spoke, in an earnest low whisper, of sounds which she then heard, but which I could not hear --of motions which she then saw, but which I could not perceive. The wind was rushing hurriedly behind the tapestries, and I wished to show her (what, let me confess it, I could not all believe) that those almost inarticulate breathings, and those very gentle variations of the figures upon the wall, were but the natural effects of that customary rushing of the wind. But a deadly pallor, overspreading her face, had proved to me that my exertions to reassure her would be fruitless. She appeared to be fainting, and no attendants were within call. I remembered where was deposited a decanter of light wine which had been ordered by her physicians, and hastened across the chamber to procure it. But, as I stepped beneath the light of the censer, two circumstances of a startling nature attracted my attention. I had felt that some palpable although invisible object had passed lightly by my person; and I saw that there lay upon the golden carpet, in the very middle of the rich lustre thrown from the censer, a shadow --a faint, indefinite shadow of angelic aspect --such as might be fancied for the shadow of a shade. But I was wild with the excitement of an immoderate dose of opium, and heeded these things but little, nor spoke of them to Rowena. Having found the wine, I recrossed the chamber, and poured out a gobletful, which I held to the lips of the fainting lady. She had now partially recovered, however, and took the vessel herself, while I sank upon an ottoman near me, with my eyes fastened upon her person. It was then that I became distinctly aware of a gentle footfall upon the carpet, and near the couch; and in a second thereafter, as Rowena was in the act of raising the wine to her lips, I saw, or may have dreamed that I saw, fall within the goblet, as if from some invisible spring in the atmosphere of the room, three or four large drops of a brilliant and ruby colored fluid. If this I saw --not so Rowena. She swallowed the wine unhesitatingly, and I forbore to speak to her of a circumstance which must, after all, I considered, have been but the suggestion of a vivid imagination, rendered morbidly active by the terror of the lady, by the opium, and by the hour.  
  
Yet I cannot conceal it from my own perception that, immediately subsequent to the fall of the ruby-drops, a rapid change for the worse took place in the disorder of my wife; so that, on the third subsequent night, the hands of her menials prepared her for the tomb, and on the fourth, I sat alone, with her shrouded body, in that fantastic chamber which had received her as my bride. --Wild visions, opium-engendered, flitted, shadow-like, before me. I gazed with unquiet eye upon the sarcophagi in the angles of the room, upon the varying figures of the drapery, and upon the writhing of the parti-colored fires in the censer overhead. My eyes then fell, as I called to mind the circumstances of a former night, to the spot beneath the glare of the censer where I had seen the faint traces of the shadow. It was there, however, no longer; and breathing with greater freedom, I turned my glances to the pallid and rigid figure upon the bed. Then rushed upon me a thousand memories of Ligeia --and then came back upon my heart, with the turbulent violence of a flood, the whole of that unutterable wo with which I had regarded her thus enshrouded. The night waned; and still, with a bosom full of bitter thoughts of the one only and supremely beloved, I remained gazing upon the body of Rowena.  
  
It might have been midnight, or perhaps earlier, or later, for I had taken no note of time, when a sob, low, gentle, but very distinct, startled me from my revery. --I felt that it came from the bed of ebony --the bed of death. I listened in an agony of superstitious terror --but there was no repetition of the sound. I strained my vision to detect any motion in the corpse --but there was not the slightest perceptible. Yet I could not have been deceived. I had heard the noise, however faint, and my soul was awakened within me. I resolutely and perseveringly kept my attention riveted upon the body. Many minutes elapsed before any circumstance occurred tending to throw light upon the mystery. At length it became evident that a slight, a very feeble, and barely noticeable tinge of color had flushed up within the cheeks, and along the sunken small veins of the eyelids. Through a species of unutterable horror and awe, for which the language of mortality has no sufficiently energetic expression, I felt my heart cease to beat, my limbs grow rigid where I sat. Yet a sense of duty finally operated to restore my self-possession. I could no longer doubt that we had been precipitate in our preparations --that Rowena still lived. It was necessary that some immediate exertion be made; yet the turret was altogether apart from the portion of the abbey tenanted by the servants --there were none within call --I had no means of summoning them to my aid without leaving the room for many minutes --and this I could not venture to do. I therefore struggled alone in my endeavors to call back the spirit ill hovering. In a short period it was certain, however, that a relapse had taken place; the color disappeared from both eyelid and cheek, leaving a wanness even more than that of marble; the lips became doubly shrivelled and pinched up in the ghastly expression of death; a repulsive clamminess and coldness overspread rapidly the surface of the body; and all the usual rigorous illness immediately supervened. I fell back with a shudder upon the couch from which I had been so startlingly aroused, and again gave myself up to passionate waking visions of Ligeia.  
  
An hour thus elapsed when (could it be possible?) I was a second time aware of some vague sound issuing from the region of the bed. I listened --in extremity of horror. The sound came again --it was a sigh. Rushing to the corpse, I saw --distinctly saw --a tremor upon the lips. In a minute afterward they relaxed, disclosing a bright line of the pearly teeth. Amazement now struggled in my bosom with the profound awe which had hitherto reigned there alone. I felt that my vision grew dim, that my reason wandered; and it was only by a violent effort that I at length succeeded in nerving myself to the task which duty thus once more had pointed out. There was now a partial glow upon the forehead and upon the cheek and throat; a perceptible warmth pervaded the whole frame; there was even a slight pulsation at the heart. The lady lived; and with redoubled ardor I betook myself to the task of restoration. I chafed and bathed the temples and the hands, and used every exertion which experience, and no little medical reading, could suggest. But in vain. Suddenly, the color fled, the pulsation ceased, the lips resumed the expression of the dead, and, in an instant afterward, the whole body took upon itself the icy chilliness, the livid hue, the intense rigidity, the sunken outline, and all the loathsome peculiarities of that which has been, for many days, a tenant of the tomb.  
  
And again I sunk into visions of Ligeia --and again, (what marvel that I shudder while I write,) again there reached my ears a low sob from the region of the ebony bed. But why shall I minutely detail the unspeakable horrors of that night? Why shall I pause to relate how, time after time, until near the period of the gray dawn, this hideous drama of revivification was repeated; how each terrific relapse was only into a sterner and apparently more irredeemable death; how each agony wore the aspect of a struggle with some invisible foe; and how each struggle was succeeded by I know not what of wild change in the personal appearance of the corpse? Let me hurry to a conclusion.  
  
The greater part of the fearful night had worn away, and she who had been dead, once again stirred --and now more vigorously than hitherto, although arousing from a dissolution more appalling in its utter hopelessness than any. I had long ceased to struggle or to move, and remained sitting rigidly upon the ottoman, a helpless prey to a whirl of violent emotions, of which extreme awe was perhaps the least terrible, the least consuming. The corpse, I repeat, stirred, and now more vigorously than before. The hues of life flushed up with unwonted energy into the countenance --the limbs relaxed --and, save that the eyelids were yet pressed heavily together, and that the bandages and draperies of the grave still imparted their charnel character to the figure, I might have dreamed that Rowena had indeed shaken off, utterly, the fetters of Death. But if this idea was not, even then, altogether adopted, I could at least doubt no longer, when, arising from the bed, tottering, with feeble steps, with closed eyes, and with the manner of one bewildered in a dream, the thing that was enshrouded advanced boldly and palpably into the middle of the apartment.  
  
I trembled not --I stirred not --for a crowd of unutterable fancies connected with the air, the stature, the demeanor of the figure, rushing hurriedly through my brain, had paralyzed --had chilled me into stone. I stirred not --but gazed upon the apparition. There was a mad disorder in my thoughts --a tumult unappeasable. Could it, indeed, be the living Rowena who confronted me? Could it indeed be Rowena at all --the fair-haired, the blue-eyed Lady Rowena Trevanion of Tremaine? Why, why should I doubt it? The bandage lay heavily about the mouth --but then might it not be the mouth of the breathing Lady of Tremaine? And the cheeks-there were the roses as in her noon of life --yes, these might indeed be the fair cheeks of the living Lady of Tremaine. And the chin, with its dimples, as in health, might it not be hers? --but had she then grown taller since her malady? What inexpressible madness seized me with that thought? One bound, and I had reached her feet! Shrinking from my touch, she let fall from her head, unloosened, the ghastly cerements which had confined it, and there streamed forth, into the rushing atmosphere of the chamber, huge masses of long and dishevelled hair; it was blacker than the raven wings of the midnight! And now slowly opened the eyes of the figure which stood before me. "Here then, at least," I shrieked aloud, "can I never --can I never be mistaken --these are the full, and the black, and the wild eyes --of my lost love --of the lady --of the LADY LIGEIA."
